@@ -11,7 +11,7 @@ from datetime import datetime, date
 md = marshal.dumps
 ml = marshal.loads
 
-class class_cached_property(object):
+class cached_classmethod(object):
     '''
     Кеширующий classmethod
     '''
@@ -31,8 +31,9 @@ class Model(object):
     ...     ustr    = UnicodeProperty(key='u')
     ...     cstr    = CompressedStringProperty()
     ...     cuni    = CompressedUnicodeProperty() 
-    ...     cdump   = CompressedProperty(default={}) 
     ...     created = DateTimeProperty(key='c')
+    ...     item    = ChoiceProperty(choices=[1, 2, 3])
+    ...     item1   = ChoiceProperty(choices=(('a', 'val1'), ('b', 'val2')))
     ...
     ...     __db_type__ = 'dict'
     
@@ -42,13 +43,15 @@ class Model(object):
     ...     ustr    = u'ыыы',
     ...     cstr    = 'A' * 1000,
     ...     cuni    = u'Ы' * 1000,
-    ...     cdump   = range(10),
     ...     created = datetime.now(),
     ... ).save()
     >>> Test(day=date(1999, 02, 02)).save()
     
-    >>> Test.get(date(1999, 02, 02)).foo
+    >>> t = Test.get(date(1999, 02, 02))
+    >>> t.foo
     [1, 2]
+    >>> t.item = 2
+    >>> t.item1 = 'val2'
     
     >>> Test.count()
     2
@@ -119,7 +122,7 @@ class Model(object):
 
     @classmethod
     def find_one(cls, filter=None, order=None):
-        for v in cls.find(filter):
+        for v in cls.find(filter, order):
             return v
 
     @classmethod
@@ -139,9 +142,13 @@ class Model(object):
         del self.db[md(pk)]
         self._data = {}
 
-    @class_cached_property
+    @cached_classmethod
     def db(cls):
         '''Отложенное подключение к бд'''
+        return cls._db_open()
+    
+    @classmethod
+    def _db_open(cls):
         if not cls.__filename__ and cls.__db_type__ != 'dict':
             assert 0, 'set __filename__ in model "%s"' % cls.__name__
         if cls.__db_type__ == 'tc':
@@ -152,30 +159,30 @@ class Model(object):
             import tokyo.cabinet as tc
             ret = tc.HDB()
             ret.open(cls.__filename__, tc.HDBOWRITER | tc.HDBOCREAT)
-            return ret
         elif cls.__db_type__ == 'kc':
             import kyotocabinet as kc
             ret = kc.DB()
             ret.open("var/test.kch", db.OWRITER | db.OCREATE)
-            return ret
         elif cls.__db_type__ == 'fsdbm':
             import fsdbm
-            return fsdbm.FSDBM(cls.__filename__)
+            ret = fsdbm.FSDBM(cls.__filename__)
         elif cls.__db_type__ == 'gdbm':
             import gdbm
-            return gdbm.open(cls.__filename__, 'c')
+            ret = gdbm.open(cls.__filename__, 'c')
         elif cls.__db_type__ == 'dict':
-            return DictDBM(cls.__filename__)
-        assert 0, 'this db is not supported'
+            ret = DictDBM(cls.__filename__)
+        else:
+            assert 0, 'this db is not supported'
+        return ret
     
-    @class_cached_property
+    @cached_classmethod
     def _pk_name(cls):
         ret = [k for k, v in cls._properties.iteritems() if v == '__pk__']
         if not ret:
             assert 0, 'primary key in model "%s" not found' % cls.__name__
         return ret[0]
     
-    @class_cached_property
+    @cached_classmethod
     def _properties(cls):
         '''
         {prop_attr_name: save_key_name}
@@ -257,11 +264,31 @@ class Property(BaseProperty):
     pass
 
 
+class ChoiceProperty(BaseProperty):
+    def __init__(self, choices, *args, **kwargs):
+        self.set_choices(choices)
+        super(self.__class__, self).__init__(*args, **kwargs)
+            
+    def set_choices(self, choices):
+        self.choices = []
+        self._choices_kv = {}
+        self._choices_vk = {}
+        for item in choices:
+            k, v = item if isinstance(item, (tuple, list)) else (item, item)
+            self.choices.append((k, v))
+            self._choices_kv[k] = v
+            self._choices_vk[v] = k
+
+    def encode(self, value):
+        return self._choices_vk[value]
+
+    def decode(self, value):
+        return self._choices_kv[value]
+
+
 class UnicodeProperty(BaseProperty):
     def encode(self, value):
         return unicode(value)
-    def decode(self, value):
-        return value
 
 
 class DateTimeProperty(BaseProperty):
@@ -305,19 +332,6 @@ class CompressedUnicodeProperty(CompressedStringProperty):
         return value.decode(self.internal_encoding, self.encoding_errors)
 
 
-class CompressedProperty(CompressedStringProperty):
-    def __init__(self, dumper='marshal', *args, **kwargs):
-        __import__(dumper)
-        self.dumper = sys.modules[dumper]
-        super(CompressedProperty, self).__init__(*args, **kwargs)
-    def encode(self, value):
-        value = self.dumper.dumps(value)
-        return super(CompressedProperty, self).encode(value)
-    def decode(self, value):
-        value = super(CompressedProperty, self).decode(value)
-        return self.dumper.loads(value)
-
-
 class DictDBM(dict):
     '''Dummy dbm for tests'''
     def __init__(self, filename=None):
